var FormOptionListConfiguration = window.FormOptionListConfiguration || {};
(function () {

	this.FORM_TYPE_UNDEFINED = 0;
	this.FORM_TYPE_CREATE    = 1;
	this.FORM_TYPE_UPDATE    = 2;
	this.FORM_TYPE_READONLY  = 3;
	this.FORM_TYPE_DISABLED  = 4;
	this.FORM_TYPE_BULKEDIT  = 6;

	this.blacklistCurriculumTopics = [
		559870018, // Performance acknowledgements
		559870026, // Subject specific (i.e. health & PE, math, science, etc.)
		559870019  // Personal graduation plans
	];

	this.blacklistInsightToImpactDashboardOrgs = [
		559870023, // EIT: Excellence in Teaching - 108709
		559870107  // University of St Thomas - 10150
	];

	// Given an optionset control and a blacklist, this will remove any options from
	// the control that are in blacklist. At the time of writing, this should only
	// be called from the model-driven app, as the optionset control comes from the
	// FormContext that isn't available in the portal.
	this.removeOptionFromOptionSet = function (control, blacklist) {

		if (control && control.getControlType() === "optionset") {

			blacklist.forEach((val) => {
				control.removeOption(val);
			});
		}
	}

	// Given an array of HTML Options and a blacklist, this will remove any options
	// from the DOM that are in blacklist.
	this.removeOptionFromHTML = function (options, blacklist) {

		if (options.length) {
			options.each((index) => {

				let optionValue = parseInt(options[index].value);
				if (blacklist.indexOf(optionValue) >= 0) {
					options[index].remove();
				}
			});
		}
	}

	this.liquidFormExists = function () {
		return $('#liquid_form').length > 0;
	}

}).call( FormOptionListConfiguration );

$(document).ready(function () {

	//
	// Here, we are making an assumption that all forms will be liquid forms and that the url is formed
	// with the path and a '/'. We are removing these elements from the url and replacing that in the
	// browse history so that the back function will return the user to the page before the form.
	//
	if (FormOptionListConfiguration.liquidFormExists()) {
		
		let currURL = new URL(window.location.href);
		// This will remove the last two elements of the url ("path/").
		let newPath = currURL.pathname.split('/').slice(0, -2);
		currURL.pathname = newPath.join('/');
		window.history.replaceState({}, null, currURL);
	}

	// Code to display a list of attached files when the number of files is > 1. This action
	// is only required within a liquid Form.
	if (FormOptionListConfiguration.liquidFormExists()) {
		var saveLblText = "Attach a file";
		var attachLbl = document.getElementById("AttachFileLabel");
		if (attachLbl) {
			saveLblText = attachLbl.textContent;
		}
  
		var attachButton = document.getElementById("AttachFile");
		
		if (attachButton) {
		
		  $("#AttachFile").change(function (e) {
  
			var fnames = [];              
			if(e.target.files.length > 7){
			  const file = document.querySelector('#AttachFile');
			  file.value = '';
			}else{
			  const file = document.querySelector('#AttachFile');
			  for (let i = 0; i < e.target.files.length; i++) {
			  var totalBytes = e.target.files[i].size;
			  if(totalBytes > 1000000){
				  var _size = Math.floor(totalBytes/1000000);  
				  if(_size > 5){
				  file.value = '';
				  } else {
					  fnames[i] = e.target.files[i].name;
				  }
			  } else {
				  fnames[i] = e.target.files[i].name;                  
			  }
			  };
			}
  
			var parentObj = document.getElementById("AttachFileLabel");
			if (parentObj) {
			  if (parentObj.hasChildNodes()) {
				   parentObj.removeChild(parentObj.firstChild);
			  }
			  if (fnames.length > 1) {       
				var div = document.createElement("div");
				var divLbl = document.createTextNode("Files Attached:")
				div.appendChild(divLbl);
				div.style["font-weight"] = "600";
				var ul = document.createElement("ul");
				div.appendChild(ul);
				for (let i = 0; i < fnames.length; i++) {
				  var li = document.createElement("li");
				  var text = document.createTextNode(fnames[i]);
				  li.appendChild(text);
				  ul.appendChild(li)
				}     
				parentObj.appendChild(div); 
			  } else if (fnames.length <= 1) {
				parentObj.textContent = saveLblText;				
			  }
			}
		  });
		}  
	}
});